[−][src]Struct sixtyfps_corelib::component::ComponentVTable
A Component is representing an unit that is allocated together
Fields
visit_children_item: unsafe extern "C" fn(_: Pin<VRef<'_, ComponentVTable>>, index: isize, order: TraversalOrder, visitor: VRefMut<'_, ItemVisitorVTable>) -> VisitChildrenResultVisit the children of the item at index index.
Note that the root item is at index 0, so passing 0 would visit the item under root (the children of root).
If you want to visit the root item, you need to pass -1 as an index.
layout_info: unsafe extern "C" fn(_: Pin<VRef<'_, ComponentVTable>>) -> LayoutInfoReturns the layout info for this component
compute_layout: unsafe extern "C" fn(_: Pin<VRef<'_, ComponentVTable>>)Will compute the layout of
input_event: unsafe extern "C" fn(_: Pin<VRef<'_, ComponentVTable>>, _: MouseEvent, _: &ComponentWindow, _: &Pin<VRef<'_, ComponentVTable>>) -> InputEventResultinput event
key_event: unsafe extern "C" fn(_: Pin<VRef<'_, ComponentVTable>>, _: &KeyEvent, _: &ComponentWindow) -> KeyEventResultkey event
focus_event: unsafe extern "C" fn(_: Pin<VRef<'_, ComponentVTable>>, _: &FocusEvent, _: &ComponentWindow) -> FocusEventResultEvent sent to transfer focus between items or to communicate window focus change.
Implementations
impl ComponentVTable[src]
pub fn new<T: Component>() -> Self[src]
Create a vtable suitable for a given type implementing the trait.