[−][src]Enum sixtyfps_corelib::PathData
PathData represents a path described by either high-level elements or low-level events and coordinates.
Variants
None is the variant when the path is empty.
Elements(SharedArray<PathElement>)The Elements variant is used to make a Path from shared arrays of elements.
Events(SharedArray<PathEvent>, SharedArray<Point>)The Events variant describes the path as a series of low-level events and associated coordinates.
Implementations
impl PathData[src]
pub fn iter(&self) -> PathDataIterator<'_>[src]
This function returns an iterator that allows traversing the path by means of lyon events.
pub fn iter_fitted(&self, width: f32, height: f32) -> PathDataIterator<'_>[src]
This function returns an iterator that allows traversing the path by means of lyon events.