[−][src]Struct sixtyfps_corelib::eventloop::ComponentWindow
The ComponentWindow is the (rust) facing public type that can render the items of components to the screen.
Implementations
impl ComponentWindow[src]
pub fn new(window_impl: Rc<dyn GenericWindow>) -> Self[src]
Creates a new instance of a CompomentWindow based on the given window implementation. Only used internally.
pub fn run(
&self,
component: Pin<VRef<'_, ComponentVTable>>,
root_item: Pin<ItemRef<'_>>
)[src]
&self,
component: Pin<VRef<'_, ComponentVTable>>,
root_item: Pin<ItemRef<'_>>
)
Spins an event loop and renders the items of the provided component in this window.
pub fn scale_factor(&self) -> f32[src]
Returns the scale factor set on the window.
pub fn set_scale_factor(&self, factor: f32)[src]
Sets an overriding scale factor for the window. This is typically only used for testing.
pub fn free_graphics_resources(&self, component: Pin<ComponentRef<'_>>)[src]
This function is called by the generated code when a component and therefore its tree of items are destroyed. The implementation typically uses this to free the underlying graphics resources cached via RenderingCache.
pub fn set_focus_item(
&self,
component: Pin<ComponentRef<'_>>,
item: Pin<VRef<'_, ItemVTable>>
)[src]
&self,
component: Pin<ComponentRef<'_>>,
item: Pin<VRef<'_, ItemVTable>>
)
Clears the focus on any previously focused item and makes the provided item the focus item, in order to receive future key events.