[−][src]Enum sixtyfps_corelib::graphics::PathElement
PathElement describes a single element on a path, such as move-to, line-to, etc.
Variants
LineTo(PathLineTo)The LineTo variant describes a line.
ArcTo(PathArcTo)The PathArcTo variant describes an arc.
Indicates that the path should be closed now by connecting to the starting point.