[−][src]Struct sixtyfps_corelib::graphics::PathLineTo
PathLineTo describes the event of moving the cursor on the path to the specified location along a straight line.
Fields
x: f32The x coordinate where the line should go to.
y: f32The y coordinate where the line should go to.
Implementations
impl PathLineTo[src]
pub const FIELD_OFFSETS: PathLineToFieldsOffsets[src]
Return a struct containing the offset of for the fields of this struct