[−][src]Struct sixtyfps_corelib::RgbaColor
RgbaColor stores the red, green, blue and alpha components of a color
with the precision of the generic parameter T. For example if T is f32,
the values are normalized between 0 and 1. If T is u8, they values range
is 0 to 255.
This is merely a helper class for use with Color.
Fields
alpha: TThe alpha component.
red: TThe red channel.
green: TThe green channel.
blue: TThe blue channel.